from django.urls import path

app_name = "django_toolshed"

urlpatterns = []
